@@ -44,10 +44,13 @@ def upgrade_suite_py_if_needed(break_on_missing_package: bool = False) -> None:
     """
     try:
         # This checks that suite-py is available in the current environment
-        subprocess.run(["pip3", "show", "suite-py"], check=True)
+        subprocess.run(["pip3", "show", "suite-py"], check=True, capture_output=True)
         # If available, upgrade (if needed)
         Package("suite_py").upgrade()
     except Exception as error:
+        logger.warning(
+            "Skipping Suite-Py autoupgrade because the package was not found in the current environment."
+        )
         if break_on_missing_package:
             raise error
 
