@@ -338,8 +338,22 @@ class QA:
                 issues.append(
                     f"Something went wront during microservice deploy step, check the logs {self._drone.get_build_and_pipeline_url(resource['name'], resource['promoted_build'], deploy_pipeline['number'])}"
                 )
+        # Check if build is running for over an hour
+        elif (
+            build["status"] == "running"
+            and self._difference_in_hours(build["started"]) >= 1
+        ):
+            issues.append(
+                f"It looks like the build is stuck, did you try to restart the build? {self._drone.get_repo_build_url(resource['name'], resource['promoted_build'])}"
+            )
 
         return issues
 
     def _filter_list(self, search_key, in_list, search_list):
         return list(filter(lambda l: l[search_key] in in_list, search_list))
+
+    def _difference_in_hours(self, unix_timestamp):
+        ts = datetime.datetime.fromtimestamp(unix_timestamp)
+        current_ts = datetime.datetime.utcnow()
+
+        return (current_ts - ts).total_seconds() / 60 / 60
