@@ -1,7 +1,6 @@
 # -*- encoding: utf-8 -*-
 import json
 import os
-import sys
 
 import yaml
 
@@ -66,7 +65,8 @@ class Config:
             logger.error(
                 f"I couldn't find any cached version for the key {key}. Turn on the VPN."
             )
-            sys.exit(-1)
+            return ""
+            # sys.exit(-1)
 
 
 def _load_local_config(conf):
