@@ -63,10 +63,14 @@ class QainitHandler:
         )
 
     def user_info(self):
-        r = self._execute("GET", "/api/v1/user").json()
-        logger.debug(json.dumps(r, indent=2))
+        r = self._execute("GET", "/api/v1/user")
 
-        return r
+        if r.status_code == 401:
+            return None
+
+        logger.debug(json.dumps(r.json(), indent=2))
+
+        return r.json()
 
     def update_user_quota(self, username, quota):
         body = {"github_username": f"{username}", "quota": f"{quota}"}
@@ -205,7 +209,7 @@ class QainitHandler:
 
         headers = {
             "Content-Type": "application/json",
-            "Authorization": "Bearer " + auth0_token,
+            "Authorization": f"Bearer {auth0_token}",
         }
         logger.debug(request_method)
         logger.debug(api_url)
@@ -219,6 +223,5 @@ class QainitHandler:
             logger.error("Some issue during call to qainit-evo: ")
             logger.error(f"Status code: {r.status_code}, response: {r.text}")
             logger.error(api_endpoint)
-            sys.exit(-1)
 
         return r
